@@ -1,4 +1,3 @@
-from datetime import datetime
 from django.conf import settings
 from django.contrib.auth import authenticate, get_user_model
 from django.utils.translation import gettext as _
@@ -35,8 +34,9 @@ class Signup(APIView):
             try:
                 user = get_user_model().objects.get(email=email)
                 if user.is_verified:
-                    content = {'detail':
-                        _('User with this Email address already exists.')}
+                    content = {
+                        'detail': _('User with this Email address already '
+                                    'exists.')}
                     return Response(content, status=status.HTTP_400_BAD_REQUEST)
 
                 try:
@@ -55,8 +55,8 @@ class Signup(APIView):
             user.last_name = last_name
             if not must_validate_email:
                 user.is_verified = True
-                send_multi_format_email('welcome_email', 
-                                        {'email': user.email,},
+                send_multi_format_email('welcome_email',
+                                        {'email': user.email, },
                                         target_email=user.email)
             user.save()
 
@@ -67,7 +67,7 @@ class Signup(APIView):
                 signup_code.send_signup_email()
 
             content = {'email': email, 'first_name': first_name,
-                'last_name': last_name}
+                       'last_name': last_name}
             return Response(content, status=status.HTTP_201_CREATED)
 
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
@@ -105,23 +105,28 @@ class Login(APIView):
             password = serializer.data['password']
             user = authenticate(email=email, password=password)
 
-            if user and user.is_verified:
-                if user.is_active:
-                    token, created = Token.objects.get_or_create(user=user)
-                    return Response({'token': token.key},
-                        status=status.HTTP_200_OK)
+            if user:
+                if user.is_verified:
+                    if user.is_active:
+                        token, created = Token.objects.get_or_create(user=user)
+                        return Response({'token': token.key},
+                                        status=status.HTTP_200_OK)
+                    else:
+                        content = {'detail': _('User account not active.')}
+                        return Response(content,
+                                        status=status.HTTP_401_UNAUTHORIZED)
                 else:
-                    content = {'detail': _('User account not active.')}
-                    return Response(content,
-                        status=status.HTTP_401_UNAUTHORIZED)
+                    content = {'detail':
+                               _('User account not verified.')}
+                    return Response(content, status=status.HTTP_401_UNAUTHORIZED)
             else:
                 content = {'detail':
-                    _('Unable to login with provided credentials.')}
+                           _('Unable to login with provided credentials.')}
                 return Response(content, status=status.HTTP_401_UNAUTHORIZED)
 
         else:
             return Response(serializer.errors,
-                status=status.HTTP_400_BAD_REQUEST)
+                            status=status.HTTP_400_BAD_REQUEST)
 
 
 class Logout(APIView):
@@ -166,7 +171,7 @@ class PasswordReset(APIView):
 
         else:
             return Response(serializer.errors,
-                status=status.HTTP_400_BAD_REQUEST)
+                            status=status.HTTP_400_BAD_REQUEST)
 
 
 class PasswordResetVerify(APIView):
@@ -176,7 +181,7 @@ class PasswordResetVerify(APIView):
         code = request.GET.get('code', '')
 
         try:
-            password_reset_code = PasswordResetCode.objects.get(code=code)
+            PasswordResetCode.objects.get(code=code)
             content = {'success': _('User verified.')}
             return Response(content, status=status.HTTP_200_OK)
         except PasswordResetCode.DoesNotExist:
@@ -199,6 +204,7 @@ class PasswordResetVerified(APIView):
                 password_reset_code = PasswordResetCode.objects.get(code=code)
                 password_reset_code.user.set_password(password)
                 password_reset_code.user.save()
+                PasswordResetCode.objects.filter(code=code).delete()
                 content = {'success': _('Password reset.')}
                 return Response(content, status=status.HTTP_200_OK)
             except PasswordResetCode.DoesNotExist:
@@ -207,7 +213,7 @@ class PasswordResetVerified(APIView):
 
         else:
             return Response(serializer.errors,
-                status=status.HTTP_400_BAD_REQUEST)
+                            status=status.HTTP_400_BAD_REQUEST)
 
 
 class PasswordChange(APIView):
@@ -229,7 +235,7 @@ class PasswordChange(APIView):
 
         else:
             return Response(serializer.errors,
-                status=status.HTTP_400_BAD_REQUEST)
+                            status=status.HTTP_400_BAD_REQUEST)
 
 
 class UserMe(APIView):
